@@ -12,7 +12,8 @@ Arnolfini.archivePopUp.activateLinks = function () {
 Arnolfini.archivePopUp.showMessage = function (href)
 {
     var title = $('<h2 class="archivePopupTitle">'+href.substr(-4)+'</h2>')
-    var message = "This year only contains undocumented events. Documentation is either not available or it is in the process of being digitised. Are you sure you want to continue to this year?";
+    var message = "At present, this year contains some entries with date information only. Further details are available by contacting ";
+    var mailtoLink = $("<a href='mailto:readingroom@arnolfini.org.uk'>readingroom@arnolfini.org.uk</a>");
     var popupDiv = $('<div class="archivepopup"></div>');
     var messageDiv = $('<div class="message"></div>');
     var cancelButton = $('<div class="cancelButton">Cancel</div>')
@@ -22,6 +23,7 @@ Arnolfini.archivePopUp.showMessage = function (href)
     $(continueButton).click(function () {window.location = href + '?showall=true'})
     
     $(messageDiv).text(message);
+    $(messageDiv).append(mailtoLink);
     $(popupDiv).append(title);
     $(popupDiv).append(messageDiv);
     $(popupDiv).append(cancelButton);
