@@ -451,9 +451,9 @@ resizer.onResize = function ()
 	{
 		try
 		{
-			$('#FrontPageManagerLeft').masonry( 'destroy' );
-			$('#portal-column-one').masonry( 'destroy' );
-			$('#portal-column-two').masonry( 'destroy' );
+			$('#FrontPageManagerLeft.masonry').masonry( 'destroy' );
+			$('#portal-column-one.masonry').masonry( 'destroy' );
+			$('#portal-column-two.masonry').masonry( 'destroy' );
 		}
 	        catch(err)
 		{
