@@ -126,18 +126,28 @@ class CommonBrowserView(BrowserView):
         return structure
     
     def getLeadMediaTag(self, item, scale="large"):
+        catalog = getToolByName(self.context, 'portal_catalog')
         if item.portal_type == 'Image':
             if hasattr(item, 'getURL'):
                 lead = item.getURL()
             else:
                 lead = item.absolute_url()
         elif hasattr(item, 'leadMedia'):
-            lead = item.leadMedia
+            leadUID = item.leadMedia
+            leadBrain = catalog.queryCatalog({"UID": leadUID})
+            if len(leadBrain) != 0:
+                lead = leadBrain[0].getURL()
+            else:
+                lead = None
         else:
-            catalog = getToolByName(self.context, 'portal_catalog')
             brains = catalog.queryCatalog({"UID": item.UID()})
             if len(brains) != 0:
-                lead = brains[0].leadMedia
+                leadUID = brains[0].leadMedia
+                leadBrain = catalog.queryCatalog({"UID": leadUID})
+                if len(leadBrain) != 0:
+                    lead = leadBrain[0].getURL()
+                else:
+                    lead = None
             else:
                 lead = None
             
