@@ -56,7 +56,7 @@ class Renderer(base.Renderer):
 
     @property
     def available(self):
-        return self.isEventPast(self.context)
+        return self.isEventPast(self.context) and self.context.start() is not None
       
     def isEventPast(self, event):
         """
